<?php
/**
 * @subpackage Cryptomus Payment Gateway for cs-cart
 * @copyright 2024 cryptomus.com
 * @author cryptomus.com
 * @Product	: Paymant plugin for Cryptomus
 * @Date	: April 2024
 * @Contact	: robert@cryptomus.com
 * @version : 1.0.0
 **/

require "cryptomus/autoload.php";
use Tygh\Enum\OrderStatuses;

function convert_to_cscart_status($merchant_status) {
    $result = OrderStatuses::OPEN;
    switch($merchant_status) {
        case 'paid':
        case 'paid_over':
            $result = OrderStatuses::PAID;
            break;

        case 'check':
        case 'process':
        case 'confirm_check':
        case 'wrong_amount_waiting':
        case 'locked':
        case 'wrong_amount':
            $result = OrderStatuses::INCOMPLETED;
            break;

        case 'fail':
        case 'system_fail':
            $result = OrderStatuses::FAILED;
            break;

        case 'cancel':
            $result = OrderStatuses::CANCELED;
            break;
    }
    return $result;
}

function get_status_message($status) {
	$messages = [
		OrderStatuses::PAID => "Payment has been completed successfully",
		OrderStatuses::INCOMPLETED => "Payment is in progress. Waiting",
		OrderStatuses::FAILED => "Payment has been failed. Try again",
		OrderStatuses::CANCELED => "Payment has been cancelled. Try again"
	];
	return $messages[$status] ?? '';
}

if (!defined('BOOTSTRAP'))
{
	die('Access denied');
}
if (defined('PAYMENT_NOTIFICATION'))
{
	$pp_response = [];
	$order_id = $_REQUEST["order_id"];
	$shop_order_id = (int)explode('_', $order_id)[1];
	$order_info = fn_get_order_info($shop_order_id);

	if (empty($processor_data))
		$processor_data = fn_get_processor_data($order_info['payment_id']);

	$merchant_uuid = $processor_data['processor_params']['merchant_uuid'];
	$payment_api_key = $processor_data['processor_params']['payment_api_key'];
	$gateway = \Cryptomus\Api\Client::payment($payment_api_key, $merchant_uuid);
	$info = $gateway->info(['order_id' => $order_id]);
	if (fn_check_payment_script('cryptomus.php', $shop_order_id)) {
		$cscart_status = convert_to_cscart_status($info['status']);
		$pp_response['order_status'] = $cscart_status;
		$pp_response['reason_text'] = get_status_message($cscart_status);
		$pp_response['transaction_id'] = $info['uuid'];
		fn_update_order_payment_info($shop_order_id, $pp_response);
		fn_change_order_status($shop_order_id, $pp_response['order_status'], '');
		fn_finish_payment($shop_order_id, $pp_response);
	}
	fn_order_placement_routines('route', $shop_order_id);
}
else
{
	$merchant_uuid = $processor_data['processor_params']['merchant_uuid'];
	$payment_api_key = $processor_data['processor_params']['payment_api_key'];
	$commission = $processor_data['processor_params']['commission'];
	$lifetime = $processor_data['processor_params']['lifetime'];
	$currency = $processor_data['processor_params']['currency'];
	$currency_rate = $processor_data['processor_params']['currency_rate'];

	$protocol = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' ? "https" : "http";
	$url = $protocol . "://" . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	$return_url = str_replace("dispatch=checkout.place_order", "dispatch=checkout.checkout", $url);

	$order_id = 'cscart_' . $order_id;
	$gateway = \Cryptomus\Api\Client::payment($payment_api_key, $merchant_uuid);
	$callback_url = fn_url("payment_notification.notify?payment=cryptomus&order_id=$order_id", AREA, 'current');

	$payment_params = [
		'amount' => (string)((double)$order_info['total'] * (double)$currency_rate),
		'currency' => $currency,
		'order_id' => $order_id,
		'url_return' => $return_url,
		'url_callback' => $callback_url,
		'url_success' => $callback_url,
		'is_payment_multiple' => true,
		'lifetime' => (string)((int)$lifetime * 3600),
		'subtract' => (string)$commission
	];
    $payment = $gateway->create($payment_params);
    $payment_url = $payment['url'];
	fn_create_payment_form($payment_url, [], 'cryptomus', true, 'get');
}
exit;
